Sub Account Endpoints
=====================

Create a Virtual Sub-account (For Master Account)
-------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_create

Query Sub-account List (For Master Account)
-------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_list

Query Sub-account Assets (For Master Account)
---------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_assets

Get Sub-account Deposit Address (For Master Account)
----------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_deposit_address

Get Sub-account Deposit History (For Master Account)
----------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_deposit_history

Get Sub-account's Status on Margin/Futures(For Master Account)
--------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_status

Enable Margin for Sub-account (For Master Account)
--------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_enable_margin

Get Detail on Sub-account's Margin Account (For Master Account)
---------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_margin_account

Get Summary of Sub-account's Margin Account (For Master Account)
----------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_margin_account_summary

Enable Futures for Sub-account (For Master Account)
---------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_enable_futures

Futures Transfer for Sub-account (For Master Account)
------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_futures_transfer

Margin Transfer for Sub-account (For Master Account)
----------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_margin_transfer

Transfer to Sub-account of Same Master (For Sub-account)
---------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_transfer_to_sub

Transfer to Master (For Sub-account)
-------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_transfer_to_master

Sub-account Transfer History (For Sub-account)
----------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_transfer_sub_account_history

Query Sub-account Futures Asset Transfer History (For Master Account)
---------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_futures_asset_transfer_history

Query Sub-account Futures Asset Transfer History (For Master Account)
---------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_futures_asset_transfer

Query Sub-account Spot Assets Summary (For Master Account)
----------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_spot_summary

Universal Transfer (For Master Account)
---------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_universal_transfer

Query Universal Transfer History (For Master Account)
-----------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_universal_transfer_history

Get Detail on Sub-account's Futures Account V2 (For Master Account)
-------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_futures_account

Get Summary of Sub-account's Futures Account V2 (For Master Account)
--------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_futures_account_summary

Get Futures Position-Risk of Sub-account V2 (For Master Account)
----------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_futures_position_risk

Query Sub-account Spot Asset Transfer History (SAPI For Master Account)
-----------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_spot_transfer_history

Enable Leverage Token for Sub-account (For Master Account)
----------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_enable_leverage_token

Deposit assets into the managed sub-account (For Investor Master Account)
-------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.managed_sub_account_deposit

Query managed sub-account asset details (For Investor Master Account)
---------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.managed_sub_account_assets

Withdrawl assets from the managed sub-account (For Investor Master Account)
---------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.managed_sub_account_withdraw

Update IP Restriction for Sub-Account API key (For Master Account)
------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_update_ip_restriction

Get IP Restriction for a Sub-account API Key (For Master Account)
-----------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_api_get_ip_restriction

Delete IP List for a Sub-account API Key (For Master Account)
-------------------------------------------------------------
.. autofunction:: binance.spot.Spot.sub_account_api_delete_ip

Query Managed Sub-account Snapshot (For Investor Master Account)
----------------------------------------------------------------
.. autofunction:: binance.spot.Spot.managed_sub_account_get_snapshot

Query Managed Sub Account Transfer Log (Investor) (USER_DATA)
-------------------------------------------------------------
.. autofunction:: binance.spot.Spot.managed_sub_account_investor_trans_log

Query Managed Sub Account Transfer Log (Trading Team) (USER_DATA)
-----------------------------------------------------------------
.. autofunction:: binance.spot.Spot.managed_sub_account_trading_trans_log

Get Managed Sub-account Deposit Address (For Investor Master Account) (USER_DATA)
---------------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.managed_sub_account_deposit_address

Query Sub-account Assets (For Master Account)
---------------------------------------------
.. autofunction:: binance.spot.Spot.query_sub_account_assets

Enable Options for Sub-account (For Master Account)
---------------------------------------------------
.. autofunction:: binance.spot.Spot.enable_options_for_sub_account

Query Sub-account Transaction Statistics (For Master Account)
-------------------------------------------------------------
.. autofunction:: binance.spot.Spot.query_sub_account_transaction_statistics

Query Managed Sub-account Margin Asset Details (For Investor Master Account)
----------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.query_managed_sub_account_margin_asset_details

Query Managed Sub-account List (For Investor)
---------------------------------------------
.. autofunction:: binance.spot.Spot.query_managed_sub_account_list

Query Managed Sub-account Futures Asset Details (For Investor Master Account)
-----------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.query_managed_sub_account_futures_asset_details

Futures Position-Risk of Sub-account (For Master Account)
---------------------------------------------------------
.. autofunction:: binance.spot.Spot.futures_position_risk_of_sub_account

Summary of Sub-account's Futures Account V2 (For Master Account)
----------------------------------------------------------------
.. autofunction:: binance.spot.Spot.summary_of_sub_account_s_futures_account

Detail on Sub-account's Futures Account (For Master Account)
------------------------------------------------------------
.. autofunction:: binance.spot.Spot.detail_on_sub_account_s_futures_account

Query Managed Sub Account Transfer Log (For Trading Team Sub Account)(USER_DATA)
--------------------------------------------------------------------------------
.. autofunction:: binance.spot.Spot.query_managed_sub_account_transfer_log
